@@ -10,6 +10,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import copy
 import uuid
 
 import netaddr
@@ -136,7 +137,7 @@ def convert_kvp_list_to_dict(kvp_list):
         key, value = convert_kvp_str_to_list(kvp_str)
         kvp_map.setdefault(key, set())
         kvp_map[key].add(value)
-    return dict((x, list(y)) for x, y in kvp_map.items())
+    return {x: list(y) for x, y in kvp_map.items()}
 
 
 def convert_none_to_empty_list(value):
@@ -181,6 +182,28 @@ def convert_to_list(data):
         return [data]
 
 
+def convert_allocation_pools_to_canonical_format(value):
+    """Convert allocation pools to canonical format.
+
+    :param value: The allocation pools which need to be checked.
+    :returns: Allocation pools with addresses in canonical format.
+    :raises InvalidInput: If the value is not a list of allocation pools.
+    """
+    if value is None:
+        return []
+    try:
+        return [
+            {
+                k: convert_ip_to_canonical_format(v)
+                for k, v in pool.items()
+            }
+            for pool in value
+        ]
+    except Exception as e:
+        raise n_exc.InvalidInput(
+            error_message=_("Invalid data format for allocation pools")) from e
+
+
 def convert_ip_to_canonical_format(value):
     """IP Address is validated and then converted to canonical format.
 
@@ -195,7 +218,12 @@ def convert_ip_to_canonical_format(value):
         ip = netaddr.IPAddress(value)
         if ip.version == constants.IP_VERSION_6:
             return str(ip.format(dialect=netaddr.ipv6_compact))
-    except (netaddr.core.AddrFormatError, ValueError):
+    except Exception:  # nosec B110
+        # netaddr may raise all kinds of exceptions (ValueError,
+        # AttributeError...) if the input is not a valid IP address. Instead of
+        # catching them one by one, just catch all exceptions at once.
+        # Obviously, it would be better if netaddr raised a particular
+        # exception specific to the library. But we don't control it.
         pass
     return value
 
@@ -328,12 +356,16 @@ def convert_to_mac_if_none(data):
 def convert_to_sanitized_mac_address(mac_address):
     """Return a MAC address with format xx:xx:xx:xx:xx:xx
 
-    :param mac_address: The MAC address value
+    :param mac_address: (string, netaddr.EUI) The MAC address value
     :return: A string with the MAC address formatted. If the MAC address
              provided is invalid, the same input value is returned; the goal
              of this method is not to validate it.
     """
     try:
+        if isinstance(mac_address, netaddr.EUI):
+            _mac_address = copy.deepcopy(mac_address)
+            _mac_address.dialect = netaddr.mac_unix_expanded
+            return str(_mac_address)
         return str(netaddr.EUI(mac_address, dialect=netaddr.mac_unix_expanded))
     except netaddr.core.AddrFormatError:
         return mac_address
